@@ -14,8 +14,14 @@ GIT_CT_STYLES_FOLDER="${GIT_CT_FOLDER}/styles"
 GIT_CT_LICENSE="${GIT_CT_FOLDER}/license.txt"
 GIT_CT_HUNSPELL="${GIT_CT_FOLDER}/hunspell"
 GIT_CT_CONFIG_H="${GIT_CT_FOLDER}/config.h"
+DOWNGRADE_PACKAGE_LOCATION="http://repo.msys2.org/mingw/x86_64"
+DOWNGRADE_PACKAGE_NAME=""
 
-
+if [ -n "${DOWNGRADE_PACKAGE_NAME}" ]
+then
+  wget "${DOWNGRADE_PACKAGE_LOCATION}/${DOWNGRADE_PACKAGE_NAME}"
+  pacman -U --noconfirm ${DOWNGRADE_PACKAGE_NAME}
+fi
 echo "build..."
 cd ${GIT_CT_FOLDER}
 ./build.sh
@@ -44,8 +50,8 @@ pushd ${NEW_MSYS2_FOLDER} > /dev/null
 mkdir -p var/lib/pacman
 mkdir -p var/log
 mkdir -p tmp
-pacman -Syu --root "${NEW_MSYS2_FOLDER}"
-pacman -S --noconfirm --root "${NEW_MSYS2_FOLDER}" \
+pacman -Syu --root ${NEW_MSYS2_FOLDER}
+pacman -S --noconfirm --root ${NEW_MSYS2_FOLDER} \
   filesystem \
   bash \
   pacman \
@@ -63,6 +69,17 @@ if [ "$_result" -ne "0" ]; then
   echo "failed to create base data via command 'pacman -S <packages names list> --noconfirm --root ${NEW_MSYS2_FOLDER}'"
   exit 1
 fi
+if [ -n "${DOWNGRADE_PACKAGE_NAME}" ]
+then
+  wget "${DOWNGRADE_PACKAGE_LOCATION}/${DOWNGRADE_PACKAGE_NAME}"
+  pacman -U --noconfirm --root ${NEW_MSYS2_FOLDER} ${DOWNGRADE_PACKAGE_NAME}
+  _result=$?
+  if [ "$_result" -ne "0" ]; then
+    echo "failed to downgrade package"
+    exit 1
+  fi
+fi
+
 popd > /dev/null
 
 
@@ -158,7 +175,7 @@ mkdir ${LOCALE_TMP}
 for element_rel in $(ls ${GIT_CT_LANGUAGES_FOLDER})
 do
   element_abs=${GIT_CT_LANGUAGES_FOLDER}/${element_rel}
-  [ -d ${element_abs} ] && mv -fv ${LOCALE}/${element_rel} ${LOCALE_TMP}/
+  [ -d ${element_abs} ] && [ -d ${LOCALE}/${element_rel} ] && mv -fv ${LOCALE}/${element_rel} ${LOCALE_TMP}/
 done
 
 rm -rf ${LOCALE}
@@ -185,8 +202,10 @@ cp -v ${GIT_CT_LICENSE} ${NEW_ROOT_FOLDER}/
 mkdir -p ${NEW_CHERRYTREE_SHARE}/data
 cp -rv ${GIT_CT_LANGUAGE_SPECS_FOLDER} ${NEW_CHERRYTREE_SHARE}/
 cp -rv ${GIT_CT_STYLES_FOLDER} ${NEW_CHERRYTREE_SHARE}/
-cp -v ${GIT_CT_DATA_FOLDER}/script3.js ${NEW_CHERRYTREE_SHARE}/data/
-cp -v ${GIT_CT_DATA_FOLDER}/styles3.css ${NEW_CHERRYTREE_SHARE}/data/
+for element_rel in script3.js styles3.css user-style.xml
+do
+  cp -v ${GIT_CT_DATA_FOLDER}/${element_rel} ${NEW_CHERRYTREE_SHARE}/data/
+done
 # share icons
 mkdir -p ${NEW_CHERRYTREE_SHARE}/icons
 cp -v ${GIT_CT_ICONS_FOLDER}/ct_home.svg ${NEW_CHERRYTREE_SHARE}/icons/
