@@ -1,7 +1,7 @@
 /*
  * ct_actions.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -34,15 +34,15 @@
 
 class CtMainWin;
 class CtImporterInterface;
-struct ct_imported_node;
+struct CtImportedNode;
 struct TocEntry;
 class CtActions
 {
 public:
-    CtActions(CtMainWin* pCtMainWin)
-    {
+    CtActions(CtMainWin* pCtMainWin) {
         _pCtMainWin = pCtMainWin;
         _find_init();
+        _validate_enable_spell_check();
     }
 
 public:
@@ -53,6 +53,7 @@ public:
     CtImageEmbFile* curr_file_anchor{nullptr};
 
 private:
+    void _validate_enable_spell_check();
     CtLinkEntry _link_entry;
 
 private:
@@ -70,53 +71,8 @@ private:
     CtExportOptions _export_options;
 
 private:
-    struct CtSearchOptions {
-        struct time_search {
-            std::time_t time;
-            bool        on;
-        };
-
-        time_search ts_cre_after;
-        time_search ts_cre_before;
-        time_search ts_mod_after;
-        time_search ts_mod_before;
-        std::string search_replace_dict_find        = "";
-        std::string search_replace_dict_replace     = "";
-        bool        search_replace_dict_match_case  = false;
-        bool        search_replace_dict_reg_exp     = false;
-        bool        search_replace_dict_whole_word  = false;
-        bool        search_replace_dict_start_word  = false;
-        bool        search_replace_dict_fw          = true;
-        int         search_replace_dict_a_ff_fa     = 0;
-        bool        search_replace_dict_idialog     = true;
-    } s_options;
-
-    struct CtSearchState {
-        bool         replace_active     = false;
-        bool         replace_subsequent = false;
-        std::string  curr_find_where    = "";
-        std::string  curr_find_pattern  = "";
-        bool         from_find_iterated = false;
-        bool         from_find_back     = false;
-        bool         newline_trick      = false;
-
-        bool         first_useful_node  = false;
-        int          counted_nodes      = 0;
-        int          processed_nodes    = 0;
-        int          latest_matches     = 0;
-
-        int          matches_num;
-        bool         all_matches_first_in_node = false;
-
-        int          latest_node_offset = -1;
-        gint64       latest_node_offset_node_id = -1;
-
-        std::unique_ptr<Gtk::Dialog> iteratedfinddialog;
-
-        Glib::RefPtr<CtMatchDialogStore> match_store;
-        std::string   match_dialog_title;
-
-    } s_state;
+    CtSearchOptions _s_options;
+    CtSearchState _s_state;
 
 public:
     CtMainWin*   getCtMainWin() { return _pCtMainWin; }
@@ -150,6 +106,8 @@ public:
     void quit_or_hide_window();
     void quit_window();
     void dialog_preferences();
+    void preferences_import();
+    void preferences_export();
     void command_palette();
 
 private:
@@ -202,7 +160,6 @@ private:
     // helpers for find actions
     void                _find_init();
     void                _find_in_all_nodes(bool for_current_node);
-    std::string         _dialog_search(const std::string& title, bool replace_on, bool multiple_nodes, bool pattern_required);
     bool                _parse_node_name(CtTreeIter node_iter, Glib::RefPtr<Glib::Regex> re_pattern, bool forward, bool all_matches);
     bool                _parse_given_node_content(CtTreeIter node_iter, Glib::RefPtr<Glib::Regex> re_pattern, bool forward, bool first_fromsel, bool all_matches);
     bool                _parse_node_content_iter(const CtTreeIter& tree_iter, Glib::RefPtr<Gtk::TextBuffer> text_buffer, Glib::RefPtr<Glib::Regex> re_pattern,
@@ -215,10 +172,14 @@ private:
     std::string         _get_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buffer, Gtk::TextIter text_iter);
     std::string         _get_first_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buffer);
     Glib::ustring       _check_pattern_in_object(Glib::RefPtr<Glib::Regex> pattern, CtAnchoredWidget* obj);
-    std::pair<int, int> _check_pattern_in_object_between(CtTreeIter tree_iter, Glib::RefPtr<Gtk::TextBuffer> text_buffer, Glib::RefPtr<Glib::Regex> pattern,
-                                                         int start_offset, int end_offset, bool forward, std::string& obj_content);
+    std::pair<int, int> _check_pattern_in_object_between(CtTreeIter tree_iter,
+                                                         Glib::RefPtr<Gtk::TextBuffer> text_buffer,
+                                                         Glib::RefPtr<Glib::Regex> pattern,
+                                                         int start_offset,
+                                                         int end_offset,
+                                                         bool forward,
+                                                         std::string& obj_content);
     int                 _get_num_objs_before_offset(Glib::RefPtr<Gtk::TextBuffer> text_buffer, int max_offset);
-    void                _iterated_find_dialog();
     void                _update_all_matches_progress();
 
 public:
@@ -227,8 +188,8 @@ public:
     void find_in_all_nodes()             { _find_in_all_nodes(false); }
     void find_in_sel_node_and_subnodes() { _find_in_all_nodes(true); }
     void find_a_node();
-    void find_again();
-    void find_back();
+    void find_again() { find_again_iter(false/*fromIterativeDialog*/); }
+    void find_back() { find_back_iter(false/*fromIterativeDialog*/); }
     void replace_in_selected_node();
     void replace_in_all_nodes();
     void replace_in_sel_node_and_subnodes();
@@ -236,8 +197,10 @@ public:
     void replace_again();
     void find_allmatchesdialog_restore();
 
-private:
-    // helpers for view actions
+public:
+    // helpers for find actions
+    void find_again_iter(const bool fromIterativeDialog);
+    void find_back_iter(const bool fromIterativeDialog);
 
 public:
     // view actions
@@ -253,29 +216,31 @@ public:
 
 public:
     // helper for format actions
-    void _apply_tag(const Glib::ustring& tag_property, Glib::ustring property_value = "",
-                    std::optional<Gtk::TextIter> iter_sel_start = std::nullopt,
-                    std::optional<Gtk::TextIter> iter_sel_end = std::nullopt,
-                    Glib::RefPtr<Gtk::TextBuffer> text_buffer = Glib::RefPtr<Gtk::TextBuffer>());
+    void apply_tag(const Glib::ustring& tag_property,
+                   Glib::ustring property_value = "",
+                   std::optional<Gtk::TextIter> iter_sel_start = std::nullopt,
+                   std::optional<Gtk::TextIter> iter_sel_end = std::nullopt,
+                   Glib::RefPtr<Gtk::TextBuffer> text_buffer = Glib::RefPtr<Gtk::TextBuffer>{});
 
 private:
     struct text_view_n_buffer_codebox_proof {
-        CtTextView*                     text_view;
-        Glib::RefPtr<Gtk::TextBuffer>   text_buffer;
-        std::string                     syntax_highl;
-        CtCodebox*                      codebox;
-        bool                            from_codebox;
+        CtTextView*  text_view;
+        std::string  syntax_highl;
+        CtCodebox*   codebox;
+        CtTable*     table;
     };
     text_view_n_buffer_codebox_proof _get_text_view_n_buffer_codebox_proof();
     CtCodebox* _codebox_in_use();
-
+    CtTable* _table_in_use();
+    void _save_tags_at_cursor_as_latest(Glib::RefPtr<Gtk::TextBuffer> rTextBuffer, int cursorOffset);
     bool _links_entries_pre_dialog(const Glib::ustring& curr_link, CtLinkEntry& link_entry);
     Glib::ustring _links_entries_post_dialog(CtLinkEntry& link_entry);
     Glib::ustring _link_check_around_cursor();
 
 public:
     // format actions
-    void apply_tag_latest();
+    void save_tags_at_cursor_as_latest();
+    void apply_tags_latest();
     void remove_text_formatting();
     void apply_tag_foreground();
     void apply_tag_background();
@@ -285,9 +250,12 @@ public:
     void apply_tag_strikethrough();
     void apply_tag_indent();
     void reduce_tag_indent();
-    void apply_tag_h1();
-    void apply_tag_h2();
-    void apply_tag_h3();
+    void apply_tag_h1() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H1); }
+    void apply_tag_h2() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H2); }
+    void apply_tag_h3() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H3); }
+    void apply_tag_h4() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H4); }
+    void apply_tag_h5() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H5); }
+    void apply_tag_h6() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H6); }
     void apply_tag_small();
     void apply_tag_superscript();
     void apply_tag_subscript();
@@ -307,6 +275,7 @@ private:
                             Gtk::TextIter* pIterBound);
     void _text_selection_change_case(gchar change_type);
     int  _find_previous_indent_margin();
+    void _apply_tag_hN(const char* tagPropScaleVal);
 
 public:
     void image_insert_png(Gtk::TextIter iter_insert, Glib::RefPtr<Gdk::Pixbuf> pixbuf,
@@ -318,7 +287,6 @@ private:
 
 public:
     // edit actions
-    void insert_spec_char_action(gunichar ch);
     void requested_step_back();
     void requested_step_ahead();
     void image_handle();
@@ -329,6 +297,7 @@ public:
     void anchor_handle();
     void toc_insert();
     void timestamp_insert();
+    void special_char_insert();
     void horizontal_rule_insert();
     void text_selection_lower_case();
     void text_selection_upper_case();
@@ -416,7 +385,7 @@ private:
     // helper for import actions
     void _import_from_file(CtImporterInterface* importer, const bool dummy_root = false) noexcept;
     void _import_from_dir(CtImporterInterface* importer, const std::string& custom_dir) noexcept;
-    void _create_imported_nodes(ct_imported_node* imported_nodes, const bool dummy_root = false);
+    void _create_imported_nodes(CtImportedNode* imported_nodes, const bool dummy_root = false);
 
 public:
     // import actions
