@@ -1,7 +1,7 @@
 /*
  * ct_config.cc
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -29,53 +29,71 @@
 #include "ct_filesystem.h"
 
 const fs::path CtConfig::ConfigFilename{"config.cfg"};
+const fs::path CtConfig::PrintPageSetupFilename{"print.cfg"};
 const fs::path CtConfig::LangFilename{"lang"};
+const fs::path CtConfig::LogFilename{"log"};
+const fs::path CtConfig::ConfigLanguageSpecsDirname{"language-specs"};
+const fs::path CtConfig::ConfigStylesDirname{"styles"};
+const fs::path CtConfig::UserStyleTemplate{"user-style.xml"};
 
 CtConfig::CtConfig()
+ : _configFilepath{fs::get_cherrytree_config_filepath()}
+ , _configFilepathTmp{_configFilepath.string() + ".tmp"}
 {
-    (void)load_from_file();
+    _initLoadFromFileOk = _load_from_file();
+    _ensure_user_styles_exist();
 }
 
-CtConfig::~CtConfig()
+CtConfig::CtConfig(const std::string filepath)
+ : _configFilepath{filepath}
 {
-    //std::cout << "~CtConfig()" << std::endl;
+    _initLoadFromFileOk = _load_from_file();
 }
 
-bool CtConfig::load_from_file(const fs::path& filepath)
+void CtConfig::move_from_tmp()
 {
+    if (not _configFilepathTmp.string().empty() and fs::exists(_configFilepathTmp)) {
+        if (not fs::move_file(_configFilepathTmp, _configFilepath)) {
+            spdlog::error("{} -> {}", _configFilepathTmp, _configFilepath);
+        }
+    }
+}
+
+bool CtConfig::_load_from_file()
+{
+    move_from_tmp();
 #ifdef _WIN32
     // compatibility with old pygtk2 version
-    if (not fs::exists(filepath)) {
-        const std::string old_pygtk2_filepath = str::replace(filepath.string(), "\\Local\\", "\\Roaming\\");
+    if (not fs::exists(_configFilepath)) {
+        const std::string old_pygtk2_filepath = str::replace(_configFilepath.string(), "\\Local\\", "\\Roaming\\");
         if (fs::exists(old_pygtk2_filepath)) {
-            fs::copy_file(old_pygtk2_filepath, filepath);
+            fs::copy_file(old_pygtk2_filepath, _configFilepath);
         }
     }
 #endif // _WIN32
-    if (fs::exists(filepath))
-    {
+    if (fs::exists(_configFilepath)) {
         _uKeyFile = std::make_unique<Glib::KeyFile>();
         try {
-            _uKeyFile->load_from_file(filepath.string());
+            _uKeyFile->load_from_file(_configFilepath.string());
         }
         catch (Glib::Error& error) {
-            spdlog::error("CtConfig {}: {}", filepath, error.what());
+            spdlog::error("CtConfig {}: {}", _configFilepath, error.what());
             return false;
         }
         _populate_data_from_keyfile();
         _uKeyFile.reset(nullptr);
-        spdlog::debug("{} parsed", filepath);
+        spdlog::debug("{} parsed", _configFilepath);
         return true;
     }
-    spdlog::warn("{} missing", filepath);
+    spdlog::warn("{} missing", _configFilepath);
     return false;
 }
 
-bool CtConfig::write_to_file(const fs::path& filepath)
+bool CtConfig::write_to_file(const std::string filepath/*= ""*/)
 {
     _uKeyFile = std::make_unique<Glib::KeyFile>();
     _populate_keyfile_from_data();
-    const bool writeSucceeded = _uKeyFile->save_to_file(filepath.string());
+    const bool writeSucceeded = _uKeyFile->save_to_file(filepath.empty() ? _configFilepathTmp.string() : filepath);
     _uKeyFile.reset(nullptr);
     return writeSucceeded;
 }
@@ -83,24 +101,19 @@ bool CtConfig::write_to_file(const fs::path& filepath)
 bool CtConfig::_populate_bool_from_keyfile(const gchar* key, bool* pTarget)
 {
     bool gotIt{false};
-    if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key))
-    {
-        try
-        {
+    if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key)) {
+        try {
             *pTarget = _uKeyFile->get_boolean(_currentGroup, key);
             gotIt = true;
         }
-        catch (Glib::KeyFileError& kferror)
-        {
-            if (kferror.code() == Glib::KeyFileError::Code::INVALID_VALUE)
-            {
+        catch (Glib::KeyFileError& kferror) {
+            if (kferror.code() == Glib::KeyFileError::Code::INVALID_VALUE) {
                 // booleans from python ConfigParser
                 Glib::ustring bool_str = _uKeyFile->get_value(_currentGroup, key);
                 *pTarget = (bool_str == "True");
                 gotIt = true;
             }
-            else
-            {
+            else {
                 _unexpected_keyfile_error(key, kferror);
             }
         }
@@ -111,15 +124,12 @@ bool CtConfig::_populate_bool_from_keyfile(const gchar* key, bool* pTarget)
 bool CtConfig::_populate_int_from_keyfile(const gchar* key, int* pTarget)
 {
     bool gotIt{false};
-    if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key))
-    {
-        try
-        {
+    if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key)) {
+        try {
             *pTarget = _uKeyFile->get_integer(_currentGroup, key);
             gotIt = true;
         }
-        catch (Glib::KeyFileError& kferror)
-        {
+        catch (Glib::KeyFileError& kferror) {
             _unexpected_keyfile_error(key, kferror);
         }
     }
@@ -129,15 +139,12 @@ bool CtConfig::_populate_int_from_keyfile(const gchar* key, int* pTarget)
 bool CtConfig::_populate_double_from_keyfile(const gchar* key, double* pTarget)
 {
     bool gotIt{false};
-    if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key))
-    {
-        try
-        {
+    if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key)) {
+        try {
             *pTarget = _uKeyFile->get_double(_currentGroup, key);
             gotIt = true;
         }
-        catch (Glib::KeyFileError& kferror)
-        {
+        catch (Glib::KeyFileError& kferror) {
             _unexpected_keyfile_error(key, kferror);
         }
     }
@@ -146,10 +153,8 @@ bool CtConfig::_populate_double_from_keyfile(const gchar* key, double* pTarget)
 
 void CtConfig::_populate_map_from_current_group(std::map<std::string, std::string> *p_map)
 {
-    if (_uKeyFile->has_group(_currentGroup))
-    {
-        for (std::string key : _uKeyFile->get_keys(_currentGroup))
-        {
+    if (_uKeyFile->has_group(_currentGroup)) {
+        for (std::string key : _uKeyFile->get_keys(_currentGroup)) {
             (*p_map)[key] = _uKeyFile->get_value(_currentGroup, key);
         }
     }
@@ -157,8 +162,7 @@ void CtConfig::_populate_map_from_current_group(std::map<std::string, std::strin
 
 void CtConfig::_populate_current_group_from_map(const std::map<std::string, std::string>& map)
 {
-    for (const auto& pair : map)
-    {
+    for (const auto& pair : map) {
         _uKeyFile->set_value(_currentGroup, pair.first, pair.second);
     }
 }
@@ -173,13 +177,11 @@ void CtConfig::_populate_keyfile_from_data()
     // [state]
     _currentGroup = "state";
     guint i{0};
-    for (const fs::path& filepath : recentDocsFilepaths)
-    {
+    for (const fs::path& filepath : recentDocsFilepaths) {
         snprintf(_tempKey, _maxTempKeySize, "doc_%d", i);
         _uKeyFile->set_string(_currentGroup, _tempKey, filepath.string());
         const CtRecentDocsRestore::iterator mapIt = recentDocsRestore.find(filepath.string());
-        if (mapIt != recentDocsRestore.end())
-        {
+        if (mapIt != recentDocsRestore.end()) {
             snprintf(_tempKey, _maxTempKeySize, "visit_%d", i);
             _uKeyFile->set_string(_currentGroup, _tempKey, mapIt->second.visited_nodes);
             snprintf(_tempKey, _maxTempKeySize, "expcol_%d", i);
@@ -188,6 +190,8 @@ void CtConfig::_populate_keyfile_from_data()
             _uKeyFile->set_string(_currentGroup, _tempKey, mapIt->second.node_path);
             snprintf(_tempKey, _maxTempKeySize, "curs_%d", i);
             _uKeyFile->set_integer(_currentGroup, _tempKey, mapIt->second.cursor_pos);
+            snprintf(_tempKey, _maxTempKeySize, "vscr_%d", i);
+            _uKeyFile->set_integer(_currentGroup, _tempKey, mapIt->second.v_adj_val);
         }
         ++i;
     }
@@ -233,6 +237,7 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_string(_currentGroup, "rt_style_scheme", rtStyleScheme);
     _uKeyFile->set_string(_currentGroup, "pt_style_scheme", ptStyleScheme);
     _uKeyFile->set_string(_currentGroup, "ta_style_scheme", taStyleScheme);
+    _uKeyFile->set_string(_currentGroup, "co_style_scheme", coStyleScheme);
     _uKeyFile->set_boolean(_currentGroup, "enable_spell_check", enableSpellCheck);
     _uKeyFile->set_string(_currentGroup, "spell_check_lang", spellCheckLang);
     _uKeyFile->set_boolean(_currentGroup, "show_line_numbers", showLineNumbers);
@@ -262,6 +267,7 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_integer(_currentGroup, "relative_wrapped_space", relativeWrappedSpace);
     _uKeyFile->set_string(_currentGroup, "h_rule", hRule);
     _uKeyFile->set_string(_currentGroup, "special_chars", specialChars.item());
+    _uKeyFile->set_string(_currentGroup, "last_special_char", lastSpecialChar);
     _uKeyFile->set_string(_currentGroup, "selword_chars", selwordChars.item());
     _uKeyFile->set_string(_currentGroup, "chars_listbul", charsListbul.item());
     _uKeyFile->set_string(_currentGroup, "chars_toc", charsToc.item());
@@ -307,6 +313,13 @@ void CtConfig::_populate_keyfile_from_data()
     _currentGroup = "colors";
     _uKeyFile->set_string(_currentGroup, "tt_def_fg", ttDefFg);
     _uKeyFile->set_string(_currentGroup, "tt_def_bg", ttDefBg);
+    _uKeyFile->set_string(_currentGroup, "scalable_h1", scalableH1.serialise());
+    _uKeyFile->set_string(_currentGroup, "scalable_h2", scalableH2.serialise());
+    _uKeyFile->set_string(_currentGroup, "scalable_h3", scalableH3.serialise());
+    _uKeyFile->set_string(_currentGroup, "scalable_h4", scalableH4.serialise());
+    _uKeyFile->set_string(_currentGroup, "scalable_h5", scalableH5.serialise());
+    _uKeyFile->set_string(_currentGroup, "scalable_h6", scalableH6.serialise());
+    _uKeyFile->set_string(_currentGroup, "scalable_small", scalableSmall.serialise());
     _uKeyFile->set_string(_currentGroup, "monospace_bg", monospaceBg);
     _uKeyFile->set_boolean(_currentGroup, "ms_dedic_font", msDedicatedFont);
     _uKeyFile->set_string(_currentGroup, "monospace_font", monospaceFont);
@@ -315,6 +328,17 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_string(_currentGroup, "col_link_node", colLinkNode);
     _uKeyFile->set_string(_currentGroup, "col_link_file", colLinkFile);
     _uKeyFile->set_string(_currentGroup, "col_link_fold", colLinkFold);
+    for (unsigned n = 1; n <= CtConst::NUM_USER_STYLES; ++n) {
+        const unsigned i = n-1;
+        _uKeyFile->set_string(_currentGroup, "style_"+std::to_string(n)+"_text_fg", userStyleTextFg[i]);
+        _uKeyFile->set_string(_currentGroup, "style_"+std::to_string(n)+"_text_bg", userStyleTextBg[i]);
+        _uKeyFile->set_string(_currentGroup, "style_"+std::to_string(n)+"_sel_fg", userStyleSelectionFg[i]);
+        _uKeyFile->set_string(_currentGroup, "style_"+std::to_string(n)+"_sel_bg", userStyleSelectionBg[i]);
+        _uKeyFile->set_string(_currentGroup, "style_"+std::to_string(n)+"_cusor", userStyleCursor[i]);
+        _uKeyFile->set_string(_currentGroup, "style_"+std::to_string(n)+"_curr_line_bg", userStyleCurrentLineBg[i]);
+        _uKeyFile->set_string(_currentGroup, "style_"+std::to_string(n)+"_linenum_fg", userStyleLineNumbersFg[i]);
+        _uKeyFile->set_string(_currentGroup, "style_"+std::to_string(n)+"_linenum_bg", userStyleLineNumbersBg[i]);
+    }
 
     // [misc]
     _currentGroup = "misc";
@@ -324,10 +348,12 @@ void CtConfig::_populate_keyfile_from_data()
     //_uKeyFile->set_boolean(_currentGroup, "use_appind", useAppInd);
     _uKeyFile->set_boolean(_currentGroup, "autosave_on", autosaveOn);
     _uKeyFile->set_integer(_currentGroup, "autosave_val", autosaveVal);
+    _uKeyFile->set_boolean(_currentGroup, "bookm_top_menu", bookmarksInTopMenu);
     _uKeyFile->set_boolean(_currentGroup, "check_version", checkVersion);
     _uKeyFile->set_boolean(_currentGroup, "word_count", wordCountOn);
     _uKeyFile->set_boolean(_currentGroup, "reload_doc_last", reloadDocLast);
     _uKeyFile->set_boolean(_currentGroup, "win_title_doc_dir", winTitleShowDocDir);
+    _uKeyFile->set_boolean(_currentGroup, "nn_header_full_path", nodeNameHeaderShowFullPath);
     _uKeyFile->set_boolean(_currentGroup, "mod_time_sentinel", modTimeSentinel);
     _uKeyFile->set_boolean(_currentGroup, "backup_copy", backupCopy);
     _uKeyFile->set_integer(_currentGroup, "backup_num", backupNum);
@@ -363,36 +389,33 @@ void CtConfig::_populate_data_from_keyfile()
         if ( _populate_string_from_keyfile("file_name", &fileName) and
              _populate_string_from_keyfile("file_dir", &fileDir) )
         {
-            if (fileName != "")
-            {
+            if (not fileName.empty()) {
                 const std::string filePath = Glib::build_filename(fileDir, fileName);
-                recentDocsFilepaths.move_or_push_front(Glib::canonicalize_filename(filePath));
+                recentDocsFilepaths.move_or_push_front(fs_canonicalize_filename(filePath));
                 savedFromPyGtk = true;
             }
         }
     }
-    for (int i=0; i<recentDocsFilepaths.maxSize; ++i)
-    {
+    for (int i = 0; i < recentDocsFilepaths.maxSize; ++i) {
         snprintf(_tempKey, _maxTempKeySize, "doc_%d", i);
         std::string filepath;
-        if (not _populate_string_from_keyfile(_tempKey, &filepath))
-        {
+        if (not _populate_string_from_keyfile(_tempKey, &filepath)) {
             break;
         }
-        filepath = Glib::canonicalize_filename(filepath);
+        filepath = fs_canonicalize_filename(filepath);
         recentDocsFilepaths.push_back(filepath);
-        if (not savedFromPyGtk)
-        {
+        if (not savedFromPyGtk) {
             CtRecentDocRestore recentDocRestore;
             snprintf(_tempKey, _maxTempKeySize, "nodep_%d", i);
-            if (_populate_string_from_keyfile(_tempKey, &recentDocRestore.node_path))
-            {
+            if (_populate_string_from_keyfile(_tempKey, &recentDocRestore.node_path)) {
                 snprintf(_tempKey, _maxTempKeySize, "visit_%d", i);
                 _populate_string_from_keyfile(_tempKey, &recentDocRestore.visited_nodes);
                 snprintf(_tempKey, _maxTempKeySize, "expcol_%d", i);
                 _populate_string_from_keyfile(_tempKey, &recentDocRestore.exp_coll_str);
                 snprintf(_tempKey, _maxTempKeySize, "curs_%d", i);
                 _populate_int_from_keyfile(_tempKey, &recentDocRestore.cursor_pos);
+                snprintf(_tempKey, _maxTempKeySize, "vscr_%d", i);
+                _populate_int_from_keyfile(_tempKey, &recentDocRestore.v_adj_val);
                 recentDocsRestore[filepath] = recentDocRestore;
             }
         }
@@ -405,28 +428,26 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_int_from_keyfile("win_size_h", &winRect[3]);
     _populate_int_from_keyfile("hpaned_pos", &hpanedPos);
     _populate_bool_from_keyfile("tree_visible", &treeVisible);
-    if (savedFromPyGtk)
-    {
+    if (savedFromPyGtk) {
         CtRecentDocRestore recentDocRestore;
-        if (_populate_string_from_keyfile("node_path", &recentDocRestore.node_path))
-        {
+        if (_populate_string_from_keyfile("node_path", &recentDocRestore.node_path)) {
             recentDocRestore.node_path = str::replace(recentDocRestore.node_path, " ", ":");
             _populate_int_from_keyfile("cursor_position", &recentDocRestore.cursor_pos);
             recentDocsRestore[recentDocsFilepaths.front().string()] = recentDocRestore;
         }
     }
     _populate_string_from_keyfile("pick_dir_import", &pickDirImport);
-    pickDirImport = Glib::canonicalize_filename(pickDirImport);
+    pickDirImport = fs_canonicalize_filename(pickDirImport);
     _populate_string_from_keyfile("pick_dir_export", &pickDirExport);
-    pickDirExport = Glib::canonicalize_filename(pickDirExport);
+    pickDirExport = fs_canonicalize_filename(pickDirExport);
     _populate_string_from_keyfile("pick_dir_file", &pickDirFile);
-    pickDirFile = Glib::canonicalize_filename(pickDirFile);
+    pickDirFile = fs_canonicalize_filename(pickDirFile);
     _populate_string_from_keyfile("pick_dir_img", &pickDirImg);
-    pickDirImg = Glib::canonicalize_filename(pickDirImg);
+    pickDirImg = fs_canonicalize_filename(pickDirImg);
     _populate_string_from_keyfile("pick_dir_csv", &pickDirCsv);
-    pickDirCsv = Glib::canonicalize_filename(pickDirCsv);
+    pickDirCsv = fs_canonicalize_filename(pickDirCsv);
     _populate_string_from_keyfile("pick_dir_cbox", &pickDirCbox);
-    pickDirCbox = Glib::canonicalize_filename(pickDirCbox);
+    pickDirCbox = fs_canonicalize_filename(pickDirCbox);
     _populate_string_from_keyfile("link_type", &linkType);
     _populate_bool_from_keyfile("show_node_name_header", &showNodeNameHeader);
     _populate_int_from_keyfile("nodes_on_node_name_header", &nodesOnNodeNameHeader);
@@ -438,33 +459,25 @@ void CtConfig::_populate_data_from_keyfile()
     // [tree]
     _currentGroup = "tree";
     int rest_exp_coll;
-    if (_populate_int_from_keyfile("rest_exp_coll", &rest_exp_coll))
-    {
+    if (_populate_int_from_keyfile("rest_exp_coll", &rest_exp_coll)) {
         restoreExpColl = static_cast<CtRestoreExpColl>(rest_exp_coll);
     }
-    if (savedFromPyGtk)
-    {
+    if (savedFromPyGtk) {
         std::string exp_coll_str;
-        if (_populate_string_from_keyfile("expanded_collapsed_string", &exp_coll_str))
-        {
+        if (_populate_string_from_keyfile("expanded_collapsed_string", &exp_coll_str)) {
             recentDocsRestore[recentDocsFilepaths.front().string()].exp_coll_str = exp_coll_str;
         }
-        for (guint i=1; i<=3; ++i)
-        {
+        for (guint i = 1; i <= 3; ++i) {
             std::string docName;
             snprintf(_tempKey, _maxTempKeySize, "expcollnam%d", i);
-            if (_populate_string_from_keyfile(_tempKey, &docName))
-            {
-                for (const fs::path& filepath : recentDocsFilepaths)
-                {
-                    if (filepath.filename() == docName)
-                    {
+            if (_populate_string_from_keyfile(_tempKey, &docName)) {
+                for (const fs::path& filepath : recentDocsFilepaths) {
+                    if (filepath.filename() == docName) {
                         CtRecentDocRestore recentDocRestore;
                         snprintf(_tempKey, _maxTempKeySize, "expcollstr%d", i);
                         _populate_string_from_keyfile(_tempKey, &recentDocRestore.exp_coll_str);
                         snprintf(_tempKey, _maxTempKeySize, "expcollsel%d", i);
-                        if (_populate_string_from_keyfile(_tempKey, &recentDocRestore.node_path))
-                        {
+                        if (_populate_string_from_keyfile(_tempKey, &recentDocRestore.node_path)) {
                             recentDocRestore.node_path = str::replace(recentDocRestore.node_path, " ", ":");
                             snprintf(_tempKey, _maxTempKeySize, "expcollcur%d", i);
                             _populate_int_from_keyfile(_tempKey, &recentDocRestore.cursor_pos);
@@ -473,8 +486,7 @@ void CtConfig::_populate_data_from_keyfile()
                     }
                 }
             }
-            else
-            {
+            else {
                 break;
             }
         }
@@ -496,6 +508,7 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_string_from_keyfile("rt_style_scheme", &rtStyleScheme);
     _populate_string_from_keyfile("pt_style_scheme", &ptStyleScheme);
     _populate_string_from_keyfile("ta_style_scheme", &taStyleScheme);
+    _populate_string_from_keyfile("co_style_scheme", &coStyleScheme);
     if (_populate_bool_from_keyfile("enable_spell_check", &enableSpellCheck))
     {
         _populate_string_from_keyfile("spell_check_lang", &spellCheckLang);
@@ -527,6 +540,7 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_int_from_keyfile("relative_wrapped_space", &relativeWrappedSpace);
     _populate_string_from_keyfile("h_rule", &hRule);
     _populate_string_from_keyfile("special_chars", &specialChars);
+    _populate_string_from_keyfile("last_special_char", &lastSpecialChar);
     _populate_string_from_keyfile("selword_chars", &selwordChars);
     _populate_string_from_keyfile("chars_listbul", &charsListbul);
     if (charsListbul.size() < CtConst::CHARS_LISTBUL_DEFAULT.size()) {
@@ -587,6 +601,21 @@ void CtConfig::_populate_data_from_keyfile()
     _currentGroup = "colors";
     _populate_string_from_keyfile("tt_def_fg", &ttDefFg);
     _populate_string_from_keyfile("tt_def_bg", &ttDefBg);
+    std::string tmpScalable;
+    _populate_string_from_keyfile("scalable_h1", &tmpScalable);
+    scalableH1.deserialise(tmpScalable.c_str(), CtConst::SCALABLE_H1_DEFAULT);
+    _populate_string_from_keyfile("scalable_h2", &tmpScalable);
+    scalableH2.deserialise(tmpScalable.c_str(), CtConst::SCALABLE_H2_DEFAULT);
+    _populate_string_from_keyfile("scalable_h3", &tmpScalable);
+    scalableH3.deserialise(tmpScalable.c_str(), CtConst::SCALABLE_H3_DEFAULT);
+    _populate_string_from_keyfile("scalable_h4", &tmpScalable);
+    scalableH4.deserialise(tmpScalable.c_str(), CtConst::SCALABLE_H4_DEFAULT);
+    _populate_string_from_keyfile("scalable_h5", &tmpScalable);
+    scalableH5.deserialise(tmpScalable.c_str(), CtConst::SCALABLE_H5_DEFAULT);
+    _populate_string_from_keyfile("scalable_h6", &tmpScalable);
+    scalableH6.deserialise(tmpScalable.c_str(), CtConst::SCALABLE_H6_DEFAULT);
+    _populate_string_from_keyfile("scalable_small", &tmpScalable);
+    scalableSmall.deserialise(tmpScalable.c_str(), CtConst::SCALABLE_SMALL_DEFAULT);
     _populate_string_from_keyfile("monospace_bg", &monospaceBg);
     _populate_bool_from_keyfile("ms_dedic_font", &msDedicatedFont);
     _populate_string_from_keyfile("monospace_font", &monospaceFont);
@@ -595,6 +624,17 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_string_from_keyfile("col_link_node", &colLinkNode);
     _populate_string_from_keyfile("col_link_file", &colLinkFile);
     _populate_string_from_keyfile("col_link_fold", &colLinkFold);
+    for (unsigned n = 1; n <= CtConst::NUM_USER_STYLES; ++n) {
+        const unsigned i = n-1;
+        _populate_string_from_keyfile("style_"+std::to_string(n)+"_text_fg", &userStyleTextFg[i]);
+        _populate_string_from_keyfile("style_"+std::to_string(n)+"_text_bg", &userStyleTextBg[i]);
+        _populate_string_from_keyfile("style_"+std::to_string(n)+"_sel_fg", &userStyleSelectionFg[i]);
+        _populate_string_from_keyfile("style_"+std::to_string(n)+"_sel_bg", &userStyleSelectionBg[i]);
+        _populate_string_from_keyfile("style_"+std::to_string(n)+"_cusor", &userStyleCursor[i]);
+        _populate_string_from_keyfile("style_"+std::to_string(n)+"_curr_line_bg", &userStyleCurrentLineBg[i]);
+        _populate_string_from_keyfile("style_"+std::to_string(n)+"_linenum_fg", &userStyleLineNumbersFg[i]);
+        _populate_string_from_keyfile("style_"+std::to_string(n)+"_linenum_bg", &userStyleLineNumbersBg[i]);
+    }
 
     // [misc]
     _currentGroup = "misc";
@@ -609,10 +649,12 @@ void CtConfig::_populate_data_from_keyfile()
     }
     _populate_bool_from_keyfile("autosave_on", &autosaveOn);
     _populate_int_from_keyfile("autosave_val", &autosaveVal);
+    _populate_bool_from_keyfile("bookm_top_menu", &bookmarksInTopMenu);
     _populate_bool_from_keyfile("check_version", &checkVersion);
     _populate_bool_from_keyfile("word_count", &wordCountOn);
     _populate_bool_from_keyfile("reload_doc_last", &reloadDocLast);
     _populate_bool_from_keyfile("win_title_doc_dir", &winTitleShowDocDir);
+    _populate_bool_from_keyfile("nn_header_full_path", &nodeNameHeaderShowFullPath);
     _populate_bool_from_keyfile("mod_time_sentinel", &modTimeSentinel);
     _populate_bool_from_keyfile("backup_copy", &backupCopy);
     _populate_int_from_keyfile("backup_num", &backupNum);
@@ -637,3 +679,47 @@ void CtConfig::_populate_data_from_keyfile()
     _currentGroup = "codexec_ext";
     _populate_map_from_current_group(&customCodexecExt);
 }
+
+void CtConfig::_ensure_user_styles_exist()
+{
+    for (unsigned n = 1; n <= CtConst::NUM_USER_STYLES; ++n) {
+        const fs::path userStyleFilepath = fs::get_cherrytree_config_user_style_filepath(n);
+        if (not fs::is_regular_file(userStyleFilepath)) {
+            update_user_style(n);
+        }
+    }
+}
+
+std::string CtConfig::get_user_style_id(const unsigned num)
+{
+    return std::string{"user-"} + std::to_string(num);
+}
+
+void CtConfig::update_user_style(const unsigned num)
+{
+    const fs::path userStyleTemplateFilepath = fs::get_cherrytree_datadir() / "data" / CtConfig::UserStyleTemplate;
+    if (not fs::is_regular_file(userStyleTemplateFilepath)) {
+        spdlog::warn("Unexp missing {}", userStyleTemplateFilepath.c_str());
+        return;
+    }
+    const fs::path userStyleDirpath = fs::get_cherrytree_config_styles_dirpath();
+    if (not fs::is_directory(userStyleDirpath)) {
+        if (g_mkdir_with_parents(userStyleDirpath.c_str(), 0755) < 0) {
+            spdlog::warn("Could not create config dir {}", userStyleDirpath.c_str());
+            return;
+        }
+    }
+    std::string userStyleText = Glib::file_get_contents(userStyleTemplateFilepath.string());
+    const unsigned i = num-1;
+    userStyleText = str::replace(userStyleText, "_userStyleId_", CtConfig::get_user_style_id(num));
+    userStyleText = str::replace(userStyleText, "_userStyleTextFg_", userStyleTextFg[i]);
+    userStyleText = str::replace(userStyleText, "_userStyleTextBg_", userStyleTextBg[i]);
+    userStyleText = str::replace(userStyleText, "_userStyleSelectionFg_", userStyleSelectionFg[i]);
+    userStyleText = str::replace(userStyleText, "_userStyleSelectionBg_", userStyleSelectionBg[i]);
+    userStyleText = str::replace(userStyleText, "_userStyleCursor_", userStyleCursor[i]);
+    userStyleText = str::replace(userStyleText, "_userStyleCurrentLineBg_", userStyleCurrentLineBg[i]);
+    userStyleText = str::replace(userStyleText, "_userStyleLineNumbersFg_", userStyleLineNumbersFg[i]);
+    userStyleText = str::replace(userStyleText, "_userStyleLineNumbersBg_", userStyleLineNumbersBg[i]);
+    const fs::path userStyleFilepath = fs::get_cherrytree_config_user_style_filepath(num);
+    Glib::file_set_contents(userStyleFilepath.string(), userStyleText);
+}
