@@ -1,7 +1,7 @@
 /*
  * ct_filesystem.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -30,12 +30,20 @@
 #include "ct_logging.h"
 #include <glibmm/miscutils.h>
 
+#if GLIBMM_MAJOR_VERSION > 2 || (GLIBMM_MAJOR_VERSION == 2 && GLIBMM_MINOR_VERSION >= 64)
+#define fs_canonicalize_filename Glib::canonicalize_filename
+#else
+#define fs_canonicalize_filename fs::legacy_canonicalize_filename
+#endif
+
 class CtConfig;
 
 namespace fs {
 
 class path;
 
+std::string legacy_canonicalize_filename(const std::string& filename, const std::string& relative_to = "");
+
 void register_exe_path_detect_if_portable(const char* exe_path);
 bool alter_locale_env_var(const std::string& key, const std::string& val);
 
@@ -67,8 +75,6 @@ void open_weblink(const std::string& link);
 void open_filepath(const path& filepath, bool open_folder_if_file_not_exists, CtConfig* config);
 void open_folderpath(const path& folderpath, CtConfig* config);
 
-std::string get_content(const path& filepath);
-
 path prepare_export_folder(const path& dir_place, path new_folder, bool overwrite_existing);
 
 CtDocType get_doc_type(const path& fileName);
@@ -90,8 +96,14 @@ bool remove(const path& p);
 path get_cherrytree_datadir();
 path get_cherrytree_localedir();
 path get_cherrytree_configdir();
-path get_cherrytree_lang_filepath();
+path get_cherrytree_print_page_setup_cfg_filepath();
+path get_cherrytree_langcfg_filepath();
+path get_cherrytree_logcfg_filepath();
+std::optional<path> get_cherrytree_logdir();
 path get_cherrytree_config_filepath();
+path get_cherrytree_config_language_specs_dirpath();
+path get_cherrytree_config_styles_dirpath();
+path get_cherrytree_config_user_style_filepath(const unsigned num);
 // Filepath is a url so not an fs::path
 std::string download_file(const std::string& filepath);
 
@@ -101,12 +113,6 @@ std::string download_file(const std::string& filepath);
 */
 class path
 {
-#ifdef _WIN32
-    static const char path_sep{'\\'};
-#else
-    static const char path_sep{'/'};
-#endif
-
 public:
     friend void swap(path& lhs, path& rhs) noexcept {
         using std::swap;
@@ -160,13 +166,11 @@ public:
     [[nodiscard]] path parent_path() const { return Glib::path_get_dirname(_path); }
     [[nodiscard]] path extension() const;
     [[nodiscard]] path stem() const;
-    [[nodiscard]] std::string native() const;
+    [[nodiscard]] std::string string_native() const;
+    [[nodiscard]] std::string string_unix() const;
 
 private:
     std::string _path;
-
-    /// From Slash to Backslash when needed
-    static std::string _get_platform_path(std::string filepath);
 };
 
 } // namespace fs
