@@ -1,7 +1,7 @@
 /*
  * ct_main_win.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -88,13 +88,13 @@ public:
         Glib::RefPtr<Gtk::CssProvider> rGtkCssProvider,
         Gsv::LanguageManager*    pGsvLanguageManager,
         Gsv::StyleSchemeManager* pGsvStyleSchemeManager,
-        Gtk::StatusIcon*         pGtkStatusIcon
+        CtStatusIcon*            pCtStatusIcon
     );
     virtual ~CtMainWin();
 
     void config_apply();
     void config_update_data_from_curr_status();
-    void text_view_apply_cursor_position(CtTreeIter& treeIter, const int cursor_pos);
+    void text_view_apply_cursor_position(CtTreeIter& treeIter, const int cursor_pos, const int v_adj_val);
 
     void update_theme();
 
@@ -119,7 +119,9 @@ public:
     void update_selected_node_statusbar_info();
 
     Glib::RefPtr<Gtk::TextBuffer>     curr_buffer() { return _ctTextview.get_buffer(); }
-    CtTreeIter                        curr_tree_iter()  { return _uCtTreestore->to_ct_tree_iter(_uCtTreeview->get_selection()->get_selected()); }
+    CtTreeIter                        curr_tree_iter()  {
+        return _uCtTreestore->to_ct_tree_iter(_uCtTreeview->get_selection()->get_selected());
+    }
     CtTreeStore&                      get_tree_store()  { return *_uCtTreestore; }
     CtTreeView&                       get_tree_view()   { return *_uCtTreeview; }
     CtTextView&                       get_text_view()   { return _ctTextview; }
@@ -136,7 +138,8 @@ public:
     Glib::RefPtr<Gtk::CssProvider>&   get_css_provider()   { return _rGtkCssProvider; }
     Gsv::LanguageManager*             get_language_manager() { return _pGsvLanguageManager; }
     Gsv::StyleSchemeManager*          get_style_scheme_manager() { return _pGsvStyleSchemeManager; }
-    Gtk::StatusIcon*                  get_status_icon() { return _pGtkStatusIcon; }
+    Gtk::StatusIcon*                  get_status_icon() { return _pCtStatusIcon->get(); }
+    Gtk::ScrolledWindow&              getScrolledwindowText() { return _scrolledwindowText; }
 
     bool&         user_active()      { return _userActive; } // use as a function, because it's easier to put breakpoint
     bool&         force_exit()       { return _forceExit; }
@@ -146,12 +149,13 @@ public:
 
 public:
     std::string               get_code_icon_name(std::string code_type);
-    Gtk::Image*               new_image_from_stock(const std::string& stockImage, Gtk::BuiltinIconSize size);
+    Gtk::Image*               new_managed_image_from_stock(const std::string& stockImage, Gtk::BuiltinIconSize size);
     void                      apply_syntax_highlighting(Glib::RefPtr<Gsv::Buffer> text_buffer, const std::string& syntax, const bool forceReApply);
     void                      reapply_syntax_highlighting(const char target/*'r':RichText, 'p':PlainTextNCode, 't':Table*/);
     void                      resetup_for_syntax(const char target/*'r':RichText, 'p':PlainTextNCode*/);
     Glib::RefPtr<Gsv::Buffer> get_new_text_buffer(const Glib::ustring& textContent=""); // pygtk: buffer_create
     const std::string         get_text_tag_name_exist_or_create(const std::string& propertyName, const std::string& propertyValue);
+    void                      apply_scalable_properties(Glib::RefPtr<Gtk::TextTag> rTextTag, CtScalableTag* pCtScalableTag);
     Glib::ustring             sourceview_hovering_link_get_tooltip(const Glib::ustring& link);
     bool                      apply_tag_try_automatic_bounds(Glib::RefPtr<Gtk::TextBuffer> text_buffer, Gtk::TextIter iter_start);
     void                      apply_tag_try_automatic_bounds_triple_click(Glib::RefPtr<Gtk::TextBuffer> text_buffer, Gtk::TextIter iter_start);
@@ -169,9 +173,9 @@ public:
 
     void menu_update_bookmark_menu_item(bool is_bookmarked);
     void menu_set_bookmark_menu_items();
+    void menu_top_optional_bookmarks_enforce();
 
     void menu_set_items_recent_documents();
-    void menu_set_items_special_chars();
     void menu_set_visible_exit_app(bool visible);
     void menu_rebuild_toolbars(bool new_toolbar);
 
@@ -187,44 +191,51 @@ public:
     void save_position()                    { get_position(_savedXpos, _savedYpos); }
     void restore_position()                 { if (_savedXpos != -1) move(_savedXpos, _savedYpos); }
 
-private:
-    bool                _on_window_key_press_event(GdkEventKey* event);
+    bool start_on_systray_is_active() const;
+    void start_on_systray_delayed_file_open_set(const std::string& filepath, const std::string& nodename);
+    bool start_on_systray_delayed_file_open_kick();
+    void set_systray_can_hide(const bool systrayCanHide) { _systrayCanHide = systrayCanHide; }
+    bool get_systray_can_hide() const { return _systrayCanHide; }
 
-    void                _on_treeview_cursor_changed(); // pygtk: on_node_changed
-    bool                _on_treeview_button_release_event(GdkEventButton* event);
-    void                _on_treeview_event_after(GdkEvent* event); // pygtk: on_event_after_tree
-    void                _on_treeview_row_activated(const Gtk::TreeModel::Path&, Gtk::TreeViewColumn*);
-    bool                _on_treeview_test_collapse_row(const Gtk::TreeModel::iterator&,const Gtk::TreeModel::Path&);
-    bool                _on_treeview_key_press_event(GdkEventKey* event);
-    bool                _on_treeview_popup_menu();
-    bool                _on_treeview_scroll_event(GdkEventScroll* event);
-    bool                _on_treeview_drag_motion(const Glib::RefPtr<Gdk::DragContext>& context,
+private:
+    bool _on_window_key_press_event(GdkEventKey* event);
+    bool _on_window_configure_event(GdkEventConfigure* configure_event);
+
+    void _on_treeview_cursor_changed(); // pygtk: on_node_changed
+    bool _on_treeview_button_release_event(GdkEventButton* event);
+    void _on_treeview_event_after(GdkEvent* event); // pygtk: on_event_after_tree
+    void _on_treeview_row_activated(const Gtk::TreeModel::Path&, Gtk::TreeViewColumn*);
+    bool _on_treeview_test_collapse_row(const Gtk::TreeModel::iterator&,const Gtk::TreeModel::Path&);
+    bool _on_treeview_key_press_event(GdkEventKey* event);
+    bool _on_treeview_popup_menu();
+    bool _on_treeview_scroll_event(GdkEventScroll* event);
+    bool _on_treeview_drag_motion(const Glib::RefPtr<Gdk::DragContext>& context,
                                                  int x,
                                                  int y,
                                                  guint time);
-    void                _on_treeview_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
-                                                        int x,
-                                                        int y,
-                                                        const Gtk::SelectionData& selection_data,
-                                                        guint info,
-                                                        guint time);
-    void                _on_treeview_drag_data_get(const Glib::RefPtr<Gdk::DragContext>& context,
-                                                   Gtk::SelectionData& selection_data,
-                                                   guint info,
-                                                   guint time);
+    void _on_treeview_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
+                                         int x,
+                                         int y,
+                                         const Gtk::SelectionData& selection_data,
+                                         guint info,
+                                         guint time);
+    void _on_treeview_drag_data_get(const Glib::RefPtr<Gdk::DragContext>& context,
+                                    Gtk::SelectionData& selection_data,
+                                    guint info,
+                                    guint time);
 
-    void                _on_textview_populate_popup(Gtk::Menu* menu);
-    bool                _on_textview_motion_notify_event(GdkEventMotion* event);
-    bool                _on_textview_visibility_notify_event(GdkEventVisibility* event);
-    void                _on_textview_size_allocate(Gtk::Allocation& allocation);
-    bool                _on_textview_event(GdkEvent* event); // pygtk: on_sourceview_event
-    void                _on_textview_event_after(GdkEvent* event); // pygtk: on_sourceview_event_after
-    bool                _on_textview_scroll_event(GdkEventScroll* event);
+    void _on_textview_populate_popup(Gtk::Menu* menu);
+    bool _on_textview_motion_notify_event(GdkEventMotion* event);
+    bool _on_textview_visibility_notify_event(GdkEventVisibility* event);
+    void _on_textview_size_allocate(Gtk::Allocation& allocation);
+    bool _on_textview_event(GdkEvent* event); // pygtk: on_sourceview_event
+    void _on_textview_event_after(GdkEvent* event); // pygtk: on_sourceview_event_after
+    bool _on_textview_scroll_event(GdkEventScroll* event);
 
-    void                _reset_CtTreestore_CtTreeview();
-    void                _ensure_curr_doc_in_recent_docs();
-    void                _zoom_tree(bool is_increase);
-    bool                _try_move_focus_to_anchored_widget_if_on_it();
+    void _reset_CtTreestore_CtTreeview();
+    void _ensure_curr_doc_in_recent_docs();
+    void _zoom_tree(bool is_increase);
+    bool _try_move_focus_to_anchored_widget_if_on_it();
 
 private:
     const bool                   _no_gui;
@@ -235,7 +246,7 @@ private:
     Glib::RefPtr<Gtk::CssProvider>  _rGtkCssProvider;
     Gsv::LanguageManager*        _pGsvLanguageManager;
     Gsv::StyleSchemeManager*     _pGsvStyleSchemeManager;
-    Gtk::StatusIcon*             _pGtkStatusIcon;
+    CtStatusIcon*                _pCtStatusIcon;
 
     std::unique_ptr<CtActions>        _uCtActions;
     std::unique_ptr<CtMenu>           _uCtMenu;
@@ -249,8 +260,7 @@ private:
     std::vector<Gtk::Toolbar*>   _pToolbars;
     CtStatusBar                  _ctStatusBar;
     CtWinHeader                  _ctWinHeader;
-    Gtk::MenuItem*               _pBookmarksSubmenu{nullptr};
-    Gtk::MenuItem*               _pSpecialCharsSubmenu{nullptr};
+    std::array<Gtk::MenuItem*,3> _pBookmarksSubmenus{nullptr,nullptr,nullptr};
     Gtk::MenuItem*               _pRecentDocsSubmenu{nullptr};
     Gtk::MenuToolButton*         _pRecentDocsMenuToolButton{nullptr};
     Gtk::ScrolledWindow          _scrolledwindowTree;
@@ -278,6 +288,10 @@ private:
     sigc::connection    _mod_time_sentinel_timout_connection;
     bool                _tree_just_auto_expanded{false};
     std::unordered_map<gint64, int> _nodesCursorPos;
+    std::unordered_map<gint64, int> _nodesVScrollPos;
+    std::string         _startOnSystray_delayedFilepath;
+    std::string         _startOnSystray_delayedNodeName;
+    bool                _systrayCanHide{true};
 
 public:
     sigc::signal<void>             signal_app_new_instance = sigc::signal<void>();
